@@ -475,14 +475,19 @@ class RKT_imagemagick
      * 対象画像のリサイズ
      *
      * @access public
-     * @param integer $width 画像の幅
-     * @param integer $height 画像の高さ
-     * @param boolean $exactly 指定サイズを厳守
+     * @param integer $width   画像の幅
+     * @param integer $height  画像の高さ
+     * @param boolean $exactly 指定サイズを厳守(縦横比無視)
      * @return boolean
      */
     function resize($width, $height, $exactly=false)
     {
-        $exactly = empty($exactly)?'':'!';
+        if ($this->infos['width'] < $width &&
+            $this->infos['height'] < $height && !$large){
+            return ;
+        }
+
+        $exactly = ($exactly)?'!':'';
         
         $command = 'convert';
 
