@@ -86,9 +86,9 @@ class WAP_community extends RKT_webapp
     function WAP_community()
     {
         $this->RKT_webapp();
-        $this->setPathInfo('sid', -1, 'string');
 
-        $objact = account::getInstance($this->sid);
+        $objact = account::getInstance();
+        $this->sid = $objact->getSessionID();
         $this->account = $objact->getInfo();
         $this->base['account'] = $this->account;
 
@@ -97,6 +97,14 @@ class WAP_community extends RKT_webapp
         /* PathInfo引数の設定 */
         $this->setPathInfo('ref_community');
         $this->set_community_info();
+
+        if (empty($this->community['id'])){
+            if (!strstr($_SERVER[PATH_INFO_KEY], 'community/edit/community')){
+                RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));
+                header('Location: '.HTTP_ACTION.'community/edit/community/'.$this->sid);
+                exit();
+            }
+        } // if (empty($this->community['id']))
         
         $this->set_base_community();
         $this->set_base_member();
