@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/07/25] 作成
  - ======================================================================== */
 
@@ -399,14 +400,47 @@ class webapp extends WAP_private
     }
 
     /**
-     * データ操作設定・実行
+     * 選択済みカテゴリの取得
      *
      * @access private
      * @return interger     データ操作結果
      */
+    function get_selected()
+    {
+        $ref_entry = $this->objmnp->getCurID();
+        $select = array();
+        $sql=
+            'SELECT '.
+                'ref_category '.
+            'FROM '.
+                DB_PREFIX.'dia_select '.
+            'WHERE '.
+                'ref_diary ='.$this->ref_diary.' AND '.
+                'ref_entry ='.$ref_entry;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return $select;
+        }
+        
+        foreach ($result as $value){
+            $select[$value['ref_category']] = $value['ref_category'];
+        }
+
+        return $select;
+    }
+
+    /**
+     * データ操作設定・実行
+     *
+     * @access private
+     * @return boolean
+     */
     function do_query_select()
     {
         $ref_entry = $this->objmnp->getCurID();
+        $selected = $this->get_selected();
         $sql=
             'SELECT '.
                 'id '.
@@ -417,12 +451,19 @@ class webapp extends WAP_private
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return false;
+        }
 
         foreach ($result as $value){
             if (empty($this->dia_select[$value['id']])){
-                $this->delete_select($value['id'], $ref_entry);
+                if (!empty($selected[$value['id']])){
+                    $this->delete_select($value['id'], $ref_entry);
+                }
             } else {
-                $this->insert_select($value['id'], $ref_entry);
+                if (empty($selected[$value['id']])){
+                    $this->insert_select($value['id'], $ref_entry);
+                }
             }
         } // foreach ($result as $value)
 
