@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/05/27] 携帯端末IDによる自動ログイン処理の追加
  -      [2006/07/29] 作成
  - ======================================================================== */
 
@@ -49,14 +50,18 @@ class webapp extends WAP_public
         $this->setTemplateFile('public/content/default.tpl');
 
         $objauth = new RKT_auth();
-        if ($objauth->autoLogin()){
+        if ($objauth->autoLoginUserAgentID()){
+            $this->update_last_login();
+            $this->sid = RKT_auth::getSessionID();
             header('Location: '.HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
+            $this->print_url(HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
             exit();
         }
         
         if ($this->account['status'] != WAP_ACC_GUEST){
             $this->update_last_login();
             header('Location: '.HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
+            $this->print_url(HTTP_ACTION.'private/home/menu/'.$this->sid.'/');
             exit();
         }
 
@@ -82,5 +87,29 @@ class webapp extends WAP_public
                 'id = '.$this->account['id'];
         return $this->objdb->exec($sql);
     }
+
+    /**
+     * リダイレクト出来ない場合の表示
+     *
+     * @access public
+     * @return void
+     **/
+    function print_url($url)
+    {
+        $body  = '<html>';
+        $body .= '<head>';
+        $body .= '<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">';
+        $body .= '<title>{$base.title}</title>';
+        $body .= '</head>';
+        $body .= '<body>';
+        $body .= '<h1 align="center"><font color="#087794">'.WAP_SYSTEM_NAME.'</font></h1><hr />';
+        $body .= '<a accesskey="0" href="'.$url.'">[0]ページ移動</a>';
+        $body .= '<hr />'.COPYRIGHT;
+        $body .= '</body>';
+        $body .= '</html>';
+
+        $body = mb_convert_encoding($body, 'SJIS', 'UTF-8');
+        print($body);
+    }
 } // webapp
 ?>
