@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/04/30] 画像クリック時のリンク先エラーを修正
+ -      [2007/04/30] 画像表示上限を３に変更
  -      [2006/08/27] ファイルパスの定数名を変更
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
  -      [2006/07/10] 作成
@@ -163,7 +165,8 @@ class webapp extends WAP_community
             'WHERE '.
                 'ref_community = '.$this->ref_community.' AND '.
                 'status = '.STATUS_PICTURE_TOPIC.' AND '.
-                'ref_relation = '.$ref_topic;
+                'ref_relation = '.$ref_topic.' '.
+            'LIMIT 3';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
