@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/08/29] 表示整形の不具合修正
  -      [2006/08/27] カテゴリを複数選択に変更
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
@@ -28,6 +29,7 @@
  - ======================================================================== */
 
 /* =-=- モジュール等の読み込み -=-= */
+require_once WEBAPP_LIB_DIR.'sql_query.php';
 require_once WEBAPP_LIB_DIR.'wap_community.php';
 
 /**
@@ -57,6 +59,8 @@ class webapp extends WAP_community
         $this->set_member();
         $this->set_topic();
         $this->set_event();
+        $this->set_item();
+        $this->set_enquete();
 
         $visibilitys = array(
             VISIBILITY_PUBLIC=>  VISIBILITY_LABEL_PUBLIC_ENTRY,
@@ -134,9 +138,7 @@ class webapp extends WAP_community
                 'act.id = nam.ref_account AND '.
                 'nam.ref_community = '.$this->ref_community .' AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
-                '(nam.status = '.STATUS_COMMUNITY_ADMIN.' OR '.
-                 'nam.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'nam.status = '.STATUS_COMMUNITY_CHANGE.') '.
+                sql_query::bitFlag('nam.status & '.STATUS_COMMUNITY_MEMBERS).' '.
             'ORDER BY '.
                 'act.last_login '.
             'LIMIT 9';
@@ -245,7 +247,7 @@ class webapp extends WAP_community
                 'tpc.id as id,'.
                 'tpc.modify as modify,'.
                 'tpc.topic as topic,'.
-                'count(cmt.id) as post '.
+                'tpc.post as post '.
             'FROM '.
                 DB_PREFIX.'com_topic tpc '.
                     'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
@@ -281,7 +283,7 @@ class webapp extends WAP_community
                 'tpc.id as id,'.
                 'tpc.modify as modify,'.
                 'tpc.topic as event,'.
-                'count(cmt.id) as post '.
+                'tpc.post as post '.
             'FROM '.
                 DB_PREFIX.'com_topic tpc '.
                     'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
@@ -304,5 +306,76 @@ class webapp extends WAP_community
         $this->Assign('events', $result);
     }
 
+    /**
+     * 記事の設定
+     *
+     * @access private
+     * @return void
+     */
+    function set_item()
+    {
+        $sql=
+            'SELECT '.
+                'tpc.id as id,'.
+                'tpc.modify as modify,'.
+                'tpc.topic as event,'.
+                'tpc.post as post '.
+            'FROM '.
+                DB_PREFIX.'com_topic tpc '.
+                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
+                    'ON tpc.id = cmt.ref_topic,'.
+                DB_PREFIX.'act_account act '.
+            'WHERE '.
+                'act.id = tpc.ref_account AND '.
+                'act.avail = '.AVAIL_ENABLE.' AND '.
+                'tpc.status = '.STATUS_TOPIC_ITEM.' AND '.
+                'tpc.ref_community = '.$this->ref_community.' '.
+            'GROUP BY '.
+                'tpc.id '.
+            'ORDER BY '.
+                'tpc.modify DESC '.
+            'LIMIT 5';
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+
+        $this->Assign('items', $result);
+    }
+
+    /**
+     * アンケートの設定
+     *
+     * @access private
+     * @return void
+     */
+    function set_enquete()
+    {
+        $sql=
+            'SELECT '.
+                'tpc.id as id,'.
+                'tpc.modify as modify,'.
+                'tpc.topic as event,'.
+                'tpc.post as post '.
+            'FROM '.
+                DB_PREFIX.'com_topic tpc '.
+                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
+                    'ON tpc.id = cmt.ref_topic,'.
+                DB_PREFIX.'act_account act '.
+            'WHERE '.
+                'act.id = tpc.ref_account AND '.
+                'act.avail = '.AVAIL_ENABLE.' AND '.
+                'tpc.status = '.STATUS_TOPIC_ENQUETE.' AND '.
+                'tpc.ref_community = '.$this->ref_community.' '.
+            'GROUP BY '.
+                'tpc.id '.
+            'ORDER BY '.
+                'tpc.modify DESC '.
+            'LIMIT 5';
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+
+        $this->Assign('enquetes', $result);
+    }
 } // webapp
 ?>
