@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] 日記コメント投稿数を記事に保存
  -      [2007/02/03] 日記コメント未読フラグ追加
  -      [2006/07/25] 作成
  - ======================================================================== */
@@ -95,6 +96,7 @@ class webapp extends WAP_private
         $this->objmnp = new RKT_manip($this->objdb,  DB_PREFIX.'dia_comment');
         $result = $this->do_query();
         if ($result == RKT_MANIP_COMPLETE){
+            $this->update_entry();
             header('Location: '.HTTP_ACTION.'private/diary/entry/complete/'.WAP_URI_SEPARATOR.'id='.$this->id.'#comment');
             exit();
         } elseif($result == RKT_MANIP_VALIDATED) {
@@ -105,6 +107,7 @@ class webapp extends WAP_private
 
         /* コメントの削除 */
         if ($this->delete_comment()){
+            $this->update_entry();
             $this->Assign('deleted', true);
         }
 
@@ -365,6 +368,37 @@ class webapp extends WAP_private
         return $this->objmnp->execute($this,$skip);
     }
 
+    /**
+     * 日記記事の更新
+     *
+     * @access private
+     * @return boolean  真偽値
+     */
+    function update_entry()
+    {
+        $sql = 
+            'SELECT '.
+                'count(*) post '.
+            'FROM '.
+                DB_PREFIX.'dia_comment '.
+            'WHERE '.
+                'ref_entry = '.$this->id;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+        $post = empty($result['post'])?0:$result['post'];
+
+        $sql =
+            'UPDATE '.
+                DB_PREFIX.'dia_entry '.
+            'SET '.
+                'post = '.$post.' '.
+            'WHERE '.
+                'id = '.$this->id;
+        return $this->objdb->exec($sql);
+    }
+
     /**
      * コメントの更新
      *
