@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] フォーマットがWYSIWYGエディタならジャンプ
  -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/09/25] sns_dia_entry.link を更新しないように変更
  -      [2006/09/17] do_query_select()のforach() Warning を除去
@@ -50,6 +51,12 @@ class webapp extends WAP_private
      */
     var $id = null;
 
+    /**
+     * プレーンエディタ
+     * @var integer
+     */
+    var $plain = null;
+
     /**
      * 日記ID
      * @var integer
@@ -88,6 +95,7 @@ class webapp extends WAP_private
 
         /* URL引数の取得 */
         $this->setSafety('id');
+        $this->setSafety('plain');
         $this->permission();
         $this->id = empty($this->id)?0:$this->id;
         $this->Assign('id', $this->id);
@@ -100,7 +108,7 @@ class webapp extends WAP_private
 
         /* アクション処理 */
         if (!empty($_REQUEST['again'])){
-            header('Location: '.HTTP_ACTION.'private/diary/post/again/'.WAP_URI_SEPARATOR.'id='.$this->id);
+            header('Location: '.HTTP_ACTION.'private/diary/post/again/'.WAP_URI_SEPARATOR.'id='.$this->id.'&plain=1');
             exit();
         }
         $this->set_ref_diary();
@@ -131,7 +139,7 @@ class webapp extends WAP_private
             exit();
         } elseif($result == RKT_MANIP_VALIDATED) {
             $_SESSION['dia_select'] = $this->dia_select;
-            header('Location: '.HTTP_ACTION.'private/diary/post/confirm/'.WAP_URI_SEPARATOR.'id='.$this->id);
+            header('Location: '.HTTP_ACTION.'private/diary/post/confirm/'.WAP_URI_SEPARATOR.'id='.$this->id.'&plain=1');
             exit();
         }
 
@@ -156,7 +164,8 @@ class webapp extends WAP_private
         }
         $sql=
             'SELECT '.
-                'id '.
+                'id,'.
+                'format '.
             'FROM '.
                 DB_PREFIX.'dia_entry '.
             'WHERE '.
@@ -170,6 +179,11 @@ class webapp extends WAP_private
         if (empty($result['id'])){
             $this->id = null;        
         }
+        /* フォーマットがWYSIWYGエディタならジャンプ */
+        if ($result['format'] == DIARY_FORMAT_HTML && empty($this->plain)){
+            header('Location: '.HTTP_ACTION.'private/diary/wysiwyg/'.WAP_URI_SEPARATOR.'id='.$this->id);
+            exit();
+        }
     }
 
     /**
@@ -204,8 +218,8 @@ class webapp extends WAP_private
      */
     function format_body($string)
     {
-        $string = str_ireplace('<br>',"\r\n",$string);
-        $string = str_ireplace('<br />',"\r\n",$string);
+        $string = preg_replace('/<br>/i',"\r\n",$string);
+        $string = preg_replace('/<br \/>/i',"\r\n",$string);
         return strip_tags($string);
     }
 
@@ -235,9 +249,6 @@ class webapp extends WAP_private
         $func = array('webapp', 'format_body');
         $this->objmnp->setInitEffect('body', array('func'=>$func, 'key'=>'body'));
 
-        /* 入力データの加工設定 */
-        $this->objmnp->setInputEffect('body', array('func'=>'strip_tags'));
-
         // 更新しない項目名
         $skip = array(
             'ref_account',
