@@ -164,8 +164,15 @@ class webapp
             echo '<script type="text/javascript">setProgress(50,1);</script>'."\r\n";
             return true;
         }
+
+        /* MySQL4.1以降用 */
+        $var = '';
+        if (WAP_DB_DRIVER == 'mysql'){
+            $var = (USE_SET_NAMES == 1)?'4.1':'';
+        }
+
         // blob.sqlはmysql.sql内に梱包
-        $filename = WORK_DIR.'sqls'.DIRECTORY_SEPARATOR.WAP_DB_DRIVER.'.sql';
+        $filename = WORK_DIR.'sqls'.DIRECTORY_SEPARATOR.WAP_DB_DRIVER.$var.'.sql';
         /* ファイルの中身を取得 */
         $handle = fopen($filename, 'r');
         if (!is_resource($handle)) {
