@@ -20,6 +20,8 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/04/21] 問合せ内容・問合せ対応インデックス追加
+--      [2007/03/23] お友達の招待インデックス追加
 --      [2007/01/18] 各種ORDER部分のインデックス追加
 --      [2006/09/17] 印刷用インデックスの追加
 --      [2006/09/05] 作成
@@ -114,6 +116,12 @@ CREATE INDEX sns_book_diary ON sns_dia_book (ref_diary);
 CREATE INDEX sns_book_account ON sns_dia_book (ref_account);
 
 -- --------------------------------------------------------
+-- 
+-- お友達の招待
+-- 
+CREATE INDEX sns_invite_hash ON sns_fri_invite (email_hash);
+CREATE INDEX sns_invite_acthash ON sns_fri_invite (ref_account,email_hash);
+
 -- 
 -- お友達のアクセスログ
 -- 
@@ -202,7 +210,14 @@ CREATE INDEX sns_picture_community ON sns_com_picture (ref_community,ref_account
 -- 問合せ内容
 -- 
 CREATE INDEX sns_inquire_account ON sns_inq_inquire (ref_account);
+CREATE INDEX sns_inquire_status ON sns_inq_inquire (status);
+CREATE INDEX sns_inquire_regist ON sns_inq_inquire (regist_date);
 
+-- 
+-- 問合せ対応
+-- 
+CREATE INDEX sns_response_inquire ON sns_inq_response (ref_inquire);
+CREATE INDEX sns_response_regist ON sns_inq_response (regist_date);
 
 
 -- --------------------------------------------------------
