@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/05/27] 会員携帯用自動ログインを追加
 --      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
@@ -223,6 +224,19 @@ CREATE TABLE `sns_act_autologin` (
   UNIQUE (`loginkey`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+-- 
+-- 会員携帯用自動ログイン
+-- 
+CREATE TABLE `sns_act_mobilelogin` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  `agent_type` int(11) NOT NULL,
+  `loginkey` varchar(32),
+  PRIMARY KEY  (`id`),
+  UNIQUE (`agent_type`, `loginkey`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
 -- 
 -- 会員退会情報
 -- 
