@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/05/27] 会員携帯用自動ログインを追加
 --      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
@@ -234,6 +235,20 @@ CREATE TABLE sns_act_autologin (
   UNIQUE (loginkey)
 );
 
+-- 
+-- 会員携帯用自動ログイン
+-- 
+CREATE SEQUENCE seq_sns_act_mobilelogin start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_act_mobilelogin (
+  id integer DEFAULT nextval('seq_sns_act_mobilelogin'::text) NOT NULL,
+  modify timestamp without time zone NOT NULL,
+  ref_account integer NOT NULL,
+  agent_type integer NOT NULL,
+  loginkey varchar(32),
+  PRIMARY KEY  (id),
+  UNIQUE (agent_type, loginkey)
+);
+
 -- 
 -- 会員退会情報
 -- 
