@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/05/27] 会員携帯用自動ログインを追加
 --      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
@@ -207,6 +208,19 @@ CREATE TABLE 'sns_act_autologin' (
   UNIQUE ('loginkey')
 );
 
+-- 
+-- 会員携帯用自動ログイン
+-- 
+CREATE TABLE 'sns_act_mobilelogin' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
+  'ref_account' integer NOT NULL,
+  'agent_type' integer NOT NULL,
+  'loginkey' varchar(32),
+  PRIMARY KEY  ('id'),
+  UNIQUE ('agent_type', 'loginkey')
+);
+
 -- 
 -- 会員退会情報
 -- 
